@@ -6,9 +6,13 @@ from .party import *
 from .invoice import *
 from .account import *
 from .tax import *
+from .geographic_codes import *
 
 def register():
     Pool.register(
+        CountryCode,
+        DepartmentCode,
+        CityCode,
         Tax,
         Company,
         Address,
