@@ -35,6 +35,14 @@ def fmt_acc(val):
     return account_code_fmt
 
 
+def getTranslated(obj, field):
+    """
+    Get the translation for selection field
+    """
+    selection = dict(obj.fields_get([field])[field]['selection'])
+    return selection[getattr(obj, field)]
+
+
 class Account:
     __name__ = 'account.account'
     cashflow = fields.Many2One('account.account.cashflow', 'Cashflow', 
@@ -350,19 +358,13 @@ class PortfolioByPartyDetailed(Report):
             if not invoices:
                 continue
 
-            #FIXME TRANSLATIONS
             for invoice in invoices:
                 sum_invoices += invoice.total_amount
                 if invoice.invoice_date:
                     invoice.aged = (now - invoice.invoice_date).days
                 else:
                     invoice.aged = ''
-                if invoice.state == 'draft':
-                    invoice.state = 'Borrador'
-                elif invoice.state == 'validated':
-                    invoice.state = 'Validada'
-                elif invoice.state == 'posted':
-                    invoice.state = 'Contabilizada'
+                invoice.state = getTranslated(invoice, 'state')
                 new_invoices.append(invoice)
 
             party.invoices = new_invoices
@@ -471,6 +473,7 @@ class TrialBalanceDetailed(Report):
         Period = pool.get('account.period')
         Company = pool.get('company.company')
         Party = pool.get('party.party')
+        FiscalYear = pool.get('account.fiscalyear')
         cursor = Transaction().cursor
 
         move = Move.__table__()
@@ -551,7 +554,6 @@ class TrialBalanceDetailed(Report):
             if data['party']:
                 select_.where = select_.where & where_party
 
-            #print tuple(select_)
             cursor.execute(*select_)
 
             res_start = cursor.fetchall()
@@ -593,6 +595,7 @@ class TrialBalanceDetailed(Report):
             accounts[code][2]['credits'] += r[3]
 
         localcontext['accounts'] = OrderedDict(sorted(accounts.items()))
+        localcontext['fiscalyear'] = FiscalYear(data['fiscalyear'])
         localcontext['start_period'] = start_period_name
         localcontext['end_period'] = end_period_name
         localcontext['company'] = Company(data['company'])
