@@ -19,7 +19,7 @@ STATES_NAME = {
 
 class Party:
     __name__ = 'party.party'
-    vat_number_city = fields.Char('VAT Number City', states={
+    vat_number_city = fields.Char('VAT Number City', size=20, states={
             'invisible': (Eval('regime_tax') != 'persona_natural'),
             })
     type_document = fields.Selection([
@@ -36,7 +36,6 @@ class Party:
             ], 'Type Document')
     regime_tax = fields.Selection([
             ('', ''),
-            ('autoretenedor', 'Autoretenedor'),
             ('persona_natural', 'Persona Natural'),
             ('regimen_simplificado', 'Regimen Simplificado'),
             ('regimen_comun', 'Regimen Comun'),
@@ -44,6 +43,7 @@ class Party:
             ('entidad_estatal', 'Entidad Estatal'),
             ('domiciliado_extranjero', 'Domiciliado en Extranjero'),
             ], 'Regimen de Impuestos')
+    autoretenedor = fields.Boolean('Autoretenedor')
     check_digit = fields.Function(fields.Integer('DV'),
             'get_check_digit')
     first_name = fields.Char('Primer Nombre', states=STATES_NAME)
@@ -53,6 +53,10 @@ class Party:
     commercial_name = fields.Char('Commercial Name')
     declarante = fields.Boolean('Declarante')
     ciiu_code = fields.Char('CIIU Code', size=4)
+    street = fields.Function(fields.Char('Street'), 'get_address')
+    country_code = fields.Function(fields.Char('Country Code'), 'get_address')
+    department_code = fields.Function(fields.Char('Department Code'), 'get_address')
+    city_code = fields.Function(fields.Char('City Code'), 'get_address')
 
     @classmethod
     def __setup__(cls):
@@ -63,6 +67,7 @@ class Party:
             ('vat_number', 'UNIQUE(vat_number)',
                 'VAT Number already exists!'),
         ]
+        cls.vat_number.size = 20
 
     @classmethod
     def search_rec_name(cls, name, clause):
@@ -106,6 +111,15 @@ class Party:
     def default_regime_tax():
         return 'regimen_comun'
 
+    def get_address(self, name):
+        for address in self.addresses:
+            if hasattr(address, name):
+                val = getattr(address, name)
+                if hasattr(val, 'code'):
+                    return getattr(val, 'code')
+                return val
+        return ''
+
 
 class BankAccountNumber:
     __name__ = 'bank.account.number'
@@ -123,6 +137,9 @@ class BankAccountNumber:
 
 class Address:
     __name__ = 'party.address'
+    country_code = fields.Many2One('party.country_code', 'Country')
+    department_code = fields.Many2One('party.department_code', 'Department')
+    city_code = fields.Many2One('party.city_code', 'City')
 
     @staticmethod
     def default_country():
@@ -133,6 +150,22 @@ class Address:
         if countries:
             return countries[0].id
 
+    @staticmethod
+    def default_country_code():
+        CountryCode = Pool().get('account.country_code')
+        countries = CountryCode.search([
+            ('code', '=', '169'),
+        ])
+        if countries:
+            return countries[0].id
+
+    @staticmethod
+    def default_invoice():
+        return True
+
+    @staticmethod
+    def default_delivery():
+        return True
 
 class Company:
     __name__ = 'company.company'
